@@ -1,5 +1,5 @@
 import serial.tools.list_ports
-print("starting")
+
 ports = serial.tools.list_ports.comports()
 
 for i in ports:
@@ -15,8 +15,7 @@ for i in ports:
     print(f"Serial Number: {i.serial_number}")
     print(f"VID: {i.vid}")
 
-print(len(ports))
 if len(ports) == 0:
     print("There are no devices connected to com ports.")
 else:
-    print("*****123*************************************************************************************")
\ No newline at end of file
+    print("******************************************************************************************")
\ No newline at end of file
